@@ -51,6 +51,7 @@ class Config(object):
         :returns: list of elements
 
         """
+        print self._tree, name
         qstr = ".//%s" % (name)
         return self._tree.findall(qstr)
 
@@ -156,6 +157,25 @@ class Form(Config):
         """Dictionary with all fields in the form. The name of the field is the
         key in the dictionary"""
 
+    def get_pages(self, root=None):
+        # Get all fields for the form.
+        pages = []
+
+        if root is None:
+            root = self._tree
+
+        # Search for fields
+        for p in root.findall('.//page'):
+            pages.append(p)
+
+        # Now search for snippets
+        for s in root.findall('.//snippet'):
+            sref = s.attrib.get('ref')
+            if sref:
+                s = self._parent.get_element('snippet', sref)
+                pages.extend(self.get_pages(s))
+        return pages
+
     def get_fields(self, root=None):
         """Returns a dictionary of included fields in the form. Fields fetched
         by searching all field elements in the form or snippets and
@@ -163,7 +183,6 @@ class Form(Config):
 
         :returns: A dictionary with the configured fields in the form. The name
         of the field is the key of the dictionary.
-
         """
 
         # Are the fields already initialized?
@@ -203,8 +222,8 @@ class Form(Config):
 
         :name: name of the field to get
         :returns: ``Field``
-
         """
+
         fields = self.get_fields()
         try:
             return fields[name]
@@ -277,7 +296,6 @@ class Field(Config):
         if options is not None:
             for option in options:
                 self.options.append((option.text, option.attrib.get('value')))
-            self.options_display = options.attrib.get('display', 'dropdown')
 
         # Help
         self.help = None
@@ -285,7 +303,12 @@ class Field(Config):
         if help is not None:
             self.help = help.text
 
+        # Renderer
         self.renderer = None
+        renderer_config = entity.find('renderer')
+        if renderer_config is not None:
+            self.renderer = Renderer(renderer_config)
+
         # Get rules
         self.rules = []
         parser = Parser()
@@ -304,3 +327,20 @@ class Field(Config):
             mode = "pre"
             expr = parser.parse(expr)
             self.rules.append(Rule(expr, msg, mode))
+
+class Renderer(Config):
+    """Configuration class for FieldRenderers. This class gives an
+    interface to the Renderer configuration for fields if the field
+    should be rendererd differently than the standard way."""
+
+    def __init__(self, entity):
+        """@todo: to be defined """
+        Config.__init__(self, entity)
+
+        # Attributes of the Renderer
+        self.render_type = entity.attrib.get('type')
+        """
+        Type of the Renderer. Known Renderers:
+        - Datepicker
+        - Textarea
+        """
